JWmatrix: JWmatrix

View source: R/JaccardWeightedMatrix.R

JWmatrixR Documentation

JWmatrix

Description

This function computes the Jaccard weighted matrix distance between all the pairs of graphs.

Usage

JWmatrix(graphL)

Arguments

graphL

list of graphs as igraph objects with the same nodes.

Value

weighted Jaccard distance matrix

Examples

data("graphL_data")
JWmatrix(graphL_data)

INetTool documentation built on March 20, 2026, 1:07 a.m.