View source: R/JaccardWeightedMean.R
| JWmean | R Documentation |
This function computes the Mean Weighted Jaccard Distance for Multilayer Networks.
JWmean(graphL)
graphL |
list of different graphs in igraph format with same nodes. |
a number: the mean distance
data("graphL_data")
JWmean(graphL_data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.