adj_rename: adj_rename

View source: R/AdjSameName.R

adj_renameR Documentation

adj_rename

Description

This function constructs a list of adjacency matrices with the same row and column names for all the matrices. The output is the object needed for consensusNet function.

Usage

adj_rename(adjL)

Arguments

adjL

list of adjacency matrices

Value

a list of adjacency matrices with the same rows and columns name.

Examples

data("tryL_data")
adj_rename(tryL_data)

INetTool documentation built on March 20, 2026, 1:07 a.m.