constructionGraph: constructionGraph

View source: R/ConstructionGraph.R

constructionGraphR Documentation

constructionGraph

Description

This function constructs graphs from data with pearson correlation and proportional thresholding (the data should be with the same names (the nodes) in columns for all the matrices).

Usage

constructionGraph(data, perc = 0.95)

Arguments

data

a list of datasets

perc

percentile (default 0.95 it takes the 5 percent of the highest weights)

Value

Threshold information (highest weight, number of edges, number of nodes, modularity with louvain method), graphs in a list for each layer and weighted adjacency matrices in a list for each layer.

Examples

data("exampleL_data")
constructionGraph(exampleL_data)

INetTool documentation built on March 20, 2026, 1:07 a.m.