densityNet: densityNet

densityNetR Documentation

densityNet

Description

This function creates a density plot of the different graphs mean weights. It can be used to search the final Threshold for the Consensus Network starting from similar networks.

Usage

densityNet(graphL)

Arguments

graphL

the list of weighted graphs in igraph format.

Value

the quantile of the mean density distribution, the quantile of the mean density distribution without the zeros, plot density distribution without the zeros

Examples

data("graphL_data")
densityNet(graphL_data)

INetTool documentation built on March 20, 2026, 1:07 a.m.