measuresNet: measuresNet

View source: R/NetworkMeasures.R

measuresNetR Documentation

measuresNet

Description

This function computes graphs and nodes measures to analyse all the layers in one shot.

Usage

measuresNet(graphL, nodes.measures = TRUE)

Arguments

graphL

a list of graphs as igraphs objects.

nodes.measures

logical, if falso it computes only graph measures, if true it computes also nodes measures (default TRUE).

Value

list of measure for each layer.

Examples

data("graphL_data")
measuresNet(graphL_data)


INetTool documentation built on March 20, 2026, 1:07 a.m.