plotINet: plotINet

plotINetR Documentation

plotINet

Description

The function plots a beginning network and the consensus in one graph with different edge colors: red edges represent edges of the consensus already present in the beginning one, while light blue edges represent new edges constructed by the consensus procedure.

Usage

plotINet(
  adj,
  graph.consensus,
  edge.width = 3,
  vertex.label.cex = 0.5,
  vertex.size = 10,
  edge.curved = 0.2,
  method = "NA",
  ...
)

Arguments

adj

one of the beginning adjacency matrices

graph.consensus

consensus network, output of the consensusNet function

edge.width

the edge width (default 3)

vertex.label.cex

the size of the vertex label (default 0.8)

vertex.size

the size of the vertex (default 10)

edge.curved

to make the edge curved (default 0.2)

method

community detection method to color the nodes one of "walktrap", "edgeBetweenness", "fastGreedy", "louvain", "spinglass", "leadingEigen", "labelProp", "infomap", "optimal" and "leiden" (default no method)

...

other parameter

Value

Union graph with beginning and consensus edge. Red edges represent edges of the consensus already present in the beginning one, while light blue edges represent new edges constructed by the consensus procedure. Community detection of the beginning graph if added.

Examples

data("adjL_data")
con <- consensusNet(adjL_data)
plotINet(adjL_data[[1]], con$graphConsensus)

INetTool documentation built on March 20, 2026, 1:07 a.m.