specificNet: specificNet

specificNetR Documentation

specificNet

Description

The function creates Case Specific Networks one for each layer to give information of the peculiar layer not present in the Consensus.

Usage

specificNet(graphL, graph.consensus)

Arguments

graphL

a list of graphs as igraphs objects.

graph.consensus

graphConsensus output of the consensusNet function.

Value

Case Specific Networks one for each layer and percentage of specificity.

Examples

data("graphL_data")
data("adjL_data")
myConsensus <- consensusNet(adjL_data)
specificNet(graphL_data, myConsensus$graphConsensus)

INetTool documentation built on March 20, 2026, 1:07 a.m.