| adj_rename | R Documentation |
This function constructs a list of adjacency matrices with the
same row and column names for all the matrices. The output is the object
needed for consensusNet function.
adj_rename(adjL)
adjL |
list of adjacency matrices |
a list of adjacency matrices with the same rows and columns name.
data("tryL_data")
adj_rename(tryL_data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.