| consensusNet | R Documentation |
This function computes the INet Algorithm for the construction of a **Consensus Network**.
consensusNet(
adjL,
threshold = 0.5,
tolerance = 0.1,
theta = 0.04,
nitermax = 50,
ncores = 2,
verbose = TRUE
)
adjL |
list of weighted adjacency matrix with weights in [0,1]. Same name in rows and columns for all the matrices. |
threshold |
threshold for the construction of the Consensus (default 0.5). Used in the last step on the similar graphs. |
tolerance |
the tolerance of differences between similar graphs for the construction of the Consensus (default 0.1). |
theta |
importance to give to the neighbourhood part of the weight (default 0.04). |
nitermax |
maximum number of iteration before stopping the algorithm (default 50). |
ncores |
number of CPU cores to use (default is 2). We suggest to use ncores equal to the number of graphs to integrate. |
verbose |
flag for verbose output (default as TRUE). |
a list of 3 types: $graphConsensus the Consensus Network, $Comparison the Jaccard weighted distances between the graphs calculated in each iteration, $similarGraphs the similar graphs before the Thresholding
data("adjL_data")
consensusNet(adjL_data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.