View source: R/ConstructionGraph.R
| constructionGraph | R Documentation |
This function constructs graphs from data with pearson correlation and proportional thresholding (the data should be with the same names (the nodes) in columns for all the matrices).
constructionGraph(data, perc = 0.95)
data |
a list of datasets |
perc |
percentile (default 0.95 it takes the 5 percent of the highest weights) |
Threshold information (highest weight, number of edges, number of nodes, modularity with louvain method), graphs in a list for each layer and weighted adjacency matrices in a list for each layer.
data("exampleL_data")
constructionGraph(exampleL_data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.