| densityNet | R Documentation |
This function creates a density plot of the different graphs mean weights. It can be used to search the final Threshold for the Consensus Network starting from similar networks.
densityNet(graphL)
graphL |
the list of weighted graphs in igraph format. |
the quantile of the mean density distribution, the quantile of the mean density distribution without the zeros, plot density distribution without the zeros
data("graphL_data")
densityNet(graphL_data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.