View source: R/NetworkMeasures.R
| measuresNet | R Documentation |
This function computes graphs and nodes measures to analyse all the layers in one shot.
measuresNet(graphL, nodes.measures = TRUE)
graphL |
a list of graphs as igraphs objects. |
nodes.measures |
logical, if falso it computes only graph measures, if true it computes also nodes measures (default TRUE). |
list of measure for each layer.
data("graphL_data")
measuresNet(graphL_data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.