| specificNet | R Documentation |
The function creates Case Specific Networks one for each layer to give information of the peculiar layer not present in the Consensus.
specificNet(graphL, graph.consensus)
graphL |
a list of graphs as igraphs objects. |
graph.consensus |
graphConsensus output of the
|
Case Specific Networks one for each layer and percentage of specificity.
data("graphL_data")
data("adjL_data")
myConsensus <- consensusNet(adjL_data)
specificNet(graphL_data, myConsensus$graphConsensus)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.